# What's this?

形態素解析器をできる限り簡単に使うことを目的にしたパッケージです。

Python2.xとPython3.xの両方で使うことを意識して作成しています。

Python2.xはPython2.7.9で、Python3.xはPython3.xで動作確認をしています。

バグ報告等はgithub issueまで。Pull requestも歓迎です。
 
# Setting up

## MeCab system

[ここ](http://taku910.github.io/mecab/)をみてMecabをインストールしてください。


## python library

このコマンドを実行すれば、必要なライブラリがインストールされます。

```
pip install -r requirement.txt
```

## install

```
[sudo] python setup.py install
```



# example usage

`examples/`をみてください。

